@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: adm.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: adm.php,v 1.3 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,11 +37,11 @@ error_reporting(E_ALL);
 // ʃvWFNg̐ݒt@C擾邽߂̏
 $is_project_dir = false;
 $is_app_name    = false;
-$project_dir    = '';
+$config_file    = '';
 $app_name       = '';
 foreach ($argv as $arg) {
     if ($is_project_dir) {
-        $project_dir    = $arg;
+        $config_file    = $arg . '/config/defines.xml';
         $is_project_dir = false;
     }
     if ($is_app_name) {
@@ -56,7 +56,7 @@ if ((array_search('-v', $argv) === false) &&
     (array_search('-h', $argv) === false) &&
     (array_search('--version', $argv) === false) &&
     (array_search('--help',    $argv) === false)) {
-    if (!$project_dir) {
+    if (!$config_file) {
         echo "[SyL error] Project directory not found.\nTry `php {$argv[0]} --help' for more information.\n";
         exit;
     }
@@ -66,20 +66,16 @@ if ((array_search('-v', $argv) === false) &&
     }
 }
 
-$define_configs = array();
-$define_configs[] = "{$project_dir}/app/{$app_name}/defines.xml";
-$define_configs[] = "{$project_dir}/config/defines.xml";
 
 $syl_dir = dirname(dirname(__FILE__));
 
 require_once $syl_dir . '/SyL.php';
 
 $config = array(
-  'action_key' => 'action',
-  'webapp_dir' => $syl_dir . '/opt/adm',
-  'app_name'   => 'generate',
-  'define'     => $define_configs,
-  'debug'      => SYL_LOG_DEBUG
+  'action_key'   => 'action',
+  'project_dir'  => $syl_dir . '/opt/adm',
+  'app_name'     => 'generate',
+  'define_after' => $config_file
 );
 
 $controller =& SyL_Controller::getController($config);
