@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowNew extends SyL_AdmFlow
@@ -100,15 +100,15 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
             // ؿʤ
             if ($data->get('adm_action_next')) {
                 // Хǡ¹
-                if ($adm->validate()) {
+                if ($this->validate($adm)) {
                     // ǧ̤
                     $form->setReadOnly(true);
                 }
             } else if ($data->get('adm_action_exe')) {
                 // Хǡ¹
-                if ($adm->validate()) {
+                if ($this->validate($adm)) {
                     // Ͽ¹
-                    $adm->insert();
+                    $this->insert($adm);
                     // λ̤إ쥯
                     SyL_Response::redirect($this->getUrl('fin') . '?adm_action=new');
                 }
@@ -141,6 +141,28 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
         $data->set('url_dir', dirname($this->getScriptName()));
     }
 
+    /**
+     * Хǡ¹
+     *
+     * @access public
+     * @param object ADM֥
+     * @return bool true: ХǡOKfalse: Хǡ󥨥顼
+     */
+    function validate(&$adm)
+    {
+        return $adm->validate();
+    }
+
+    /**
+     * Ͽ¹
+     *
+     * @access public
+     * @param object ADM֥
+     */
+    function insert(&$adm)
+    {
+        $adm->insert();
+    }
 }
 
 ?>
