@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationDel.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationDel.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationDel.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationDel.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationDel extends SyL_AdmOperation
@@ -60,7 +60,7 @@ class SyL_AdmOperationDel extends SyL_AdmOperation
                 // 索֥Ⱥ
                 $conditions = $this->dao->createCondition();
                 // 祭糧å
-                $this->setConditionKey($conditions, $alias);
+                $this->setConditionKey($conditions, $alias, true);
                 // 索֥ȥå
                 $table->setConditions($conditions);
                 break;
