@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -61,10 +61,20 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
             $limit = $this->form->getStructConfig('page_records');
         }
 
+        // ץDBƤ
+        $data_sources = $this->form->getDataSources();
+
         $tables = array();
         // ơ֥륪֥Ⱥ롼
         foreach (array_keys($this->tables) as $alias) {
             $table =& $this->tables[$alias];
+            // ץDBƤ硢ɲäǥå
+            foreach ($data_sources as $name => $data_source) {
+                if ($alias == $data_source['alias']) {
+                    $table->addColumn($data_source['name'], $name);
+                }
+            }
+
             // 
             $conditions = $this->dao->createCondition();
             foreach ($this->form->getValues($alias) as $column => $value) {
@@ -83,7 +93,7 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
                         $conditions->addLike($column, '%' . $this->conn->escapeLike($value) . '%');
                     }
                 }
-            }
+            } 
             $table->setConditions($conditions);
             // 
             foreach ($sorts as $sort) {
@@ -99,7 +109,8 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         $this->dao->setPage($page, $limit);
         // ɽǡ
         $results = $this->dao->select($tables, $this->relation);
-        
+
+        // ץɽ̾Ѵ
         $options = array();
         foreach (array_keys($this->dao->getSelectHeaders()) as $name) {
             $options[$name] = $this->form->getOption($name);
