@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,7 +52,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Adm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.5 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.6 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlow extends AppAction
@@ -107,8 +107,11 @@ class SyL_AdmFlow extends AppAction
      */
     function &getForm()
     {
-        $form =& SyL_AdmActionForm::factory($this->classname);
-        $form->setType($this->opp_name);
+        static $form = null;
+        if ($form == null) {
+            $form =& SyL_AdmActionForm::factory($this->classname);
+            $form->setType($this->opp_name);
+        }
         return $form;
     }
 
