@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.6 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.7 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -326,25 +326,36 @@ class SyL_AdmOperation
      * @access protected
      * @param object 索֥
      * @param string ơ֥̾
-     * @return bool true: 顼ʤfalse: 顼
+     * @param bool ƤΥ
      */
-    function setConditionKey(&$conditions, $alias)
+    function setConditionKey(&$conditions, $alias, $all=false)
     {
         if (count($this->keys) == 0) {
-            return false;
+            return;
         }
-        $valid = true;
-        $and   = false;
+
         $primaries = $this->getPrimary(true);
-        foreach ($this->keys[0] as $name => $value) {
-            if (array_search("{$alias}.{$name}", $primaries) === false) {
-                $valid = false;
-                break;
+        if ($all) {
+            foreach ($this->keys as $key) {
+                $and = false;
+                foreach ($key as $name => $value) {
+                    if (array_search("{$alias}.{$name}", $primaries) === false) {
+                        break;
+                    }
+                    $conditions->addEqual($name, $value, true, $and);
+                    $and = true;
+                }
+            }
+        } else {
+            $and = false;
+            foreach ($this->keys[0] as $name => $value) {
+                if (array_search("{$alias}.{$name}", $primaries) === false) {
+                    break;
+                }
+                $conditions->addEqual($name, $value, true, $and);
+                $and = true;
             }
-            $conditions->addEqual($name, $value, true, $and);
-            $and = true;
         }
-        return $valid;
     }
 
     /**
@@ -385,7 +396,7 @@ class SyL_AdmOperation
      */
     function getKey()
     {
-        return (count($this->keys) > 0) ? $this->keys[0] : '';
+        return (count($this->keys) > 0) ? $this->keys[0] : array();
     }
 
     /**
