@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.7 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.7 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.8 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -165,6 +165,17 @@ class SyL_ContextJs extends SyL_Context
         return isset($_SERVER['PHP_SELF']) ? $_SERVER['PHP_SELF'] : null;
     }
 
+    /**
+     * ĶѿꥯURLREQUEST_URIˤ
+     *
+     * @access public
+     * @return string PHP_SELF
+     */
+    function getRequestUri()
+    {
+        return isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : null;
+    }
+
     /**
      * ĶѿPATHINFO
      *
