@@ -27,17 +27,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.11 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.12 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-/**
- * JavaScriptϥȥ饯饹
- */
-require_once 'SyL_ControllerJs.php';
-
-
 /**
  * WEBȥ饯饹
  *
@@ -54,11 +48,32 @@ require_once 'SyL_ControllerJs.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.11 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerWeb.php,v 1.12 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_ControllerWeb extends SyL_ControllerJs
+class SyL_ControllerWeb extends SyL_Controller
 {
+    /**
+     * ȥݥ
+     *
+     * @access public
+     */
+    function stream()
+    {
+        // 
+        $this->initStream();
+        // ¹
+        $this->loadStream();
+        // ¹Խ
+        $this->executeStream();
+        // ӥ塼ɽ¹
+        $this->middleStream();
+        // ӥ塼ɽ¹
+        $this->renderStream();
+        // ӥ塼ɽ¹Ը
+        $this->unloadStream();
+    }
+
     /**
      * ƥץ졼ȥǥ쥯ȥ
      *
