@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.12 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.13 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.12 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.13 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
@@ -62,10 +62,7 @@ class SyL_ErrorCmd extends SyL_Error
         $error_message = implode($this->eol, $error_messages) . $this->eol;
         // 顼åɽ
         echo $error_message;
-        if ($error_trace) {
-            echo $this->eol;
-            echo $this->getTraceConsole($error_trace);
-        }
+        echo $this->getTraceConsole($error_trace);
     }
 
     /**
@@ -79,6 +76,8 @@ class SyL_ErrorCmd extends SyL_Error
     {
         $error_trace_result = '';
         if (count($error_trace) > 0) {
+            $error_trace_result = $this->eol;
+
             // 顼ȥ졼ɽκ
             $error_trace_result .= "------ start Stack Trace ------" . $this->eol;
             foreach ($error_trace as $value) {
