@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.4 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.5 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Action
@@ -196,15 +196,17 @@ class SyL_Action
      */
     function &getActionForm(&$data, $form_class, $first=false)
     {
-        // ե।󥯥롼
-        include_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
-        // ե
-        $form =& SyL_ActionForm::factory($form_class);
-        // ǡ֥ȥå
-        $form->registerInput($data);
-        // ե๽
-        $form->build($first);
-
+        $form = null;
+        if ($form == null) {
+            // ե।󥯥롼
+            include_once SYL_INCLUDE_DIR . '/framework/SyL_ActionForm.php';
+            // ե
+            $form =& SyL_ActionForm::factory($form_class);
+            // ǡ֥ȥå
+            $form->registerInput($data);
+            // ե๽
+            $form->build($first);
+        }
         return $form;
     }
 
