@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.8 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.9 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.8 2007/10/15 13:56:43 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.9 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -80,9 +80,12 @@ class SyL_ActionForm extends SyL_Form
      */
     function &factory($formpath, $action='')
     {
-        $classname = SyL_Loader::convertClass($formpath, true);
-        $form =& new $classname($action);
-        return $form;
+        static $forms = array();
+        if (!isset($forms[$formpath])) {
+            $classname = SyL_Loader::convertClass($formpath, true);
+            $forms[$formpath] = new $classname($action);
+        }
+        return $forms[$formpath];
     }
 
     /**
@@ -155,6 +158,27 @@ class SyL_ActionForm extends SyL_Form
             $this->addElement($element);
         }
     }
+
+    /**
+     * եǤǼ
+     *
+     * @access public
+     * @return array եǤ
+     */
+    function &getResultArray()
+    {
+        $results =& parent::getResultArray();
+        if (!$results['read_only']) {
+            foreach (array_keys($results['elements']) as $name) {
+                if (isset($this->elements_config[$name])) {
+                    if (isset($this->elements_config[$name]['note']) && $this->elements_config[$name]['note']) {
+                        $results['elements'][$name]['html'] .= sprintf('<br><span class="note">%s</span>', $this->elements_config[$name]['note']);
+                    }
+                }
+            }
+        }
+        return $results;
+    }
 }
 
 ?>
