@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,11 +48,39 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Cache.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Config.php,v 1.16 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Config.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Config extends SyL_XmlReader
 {
+    /**
+     * ٥̾
+     * 
+     * @access protected
+     * @var string
+     */
+    var $event = '';
+    /**
+     * ǥեȼ¹Խ
+     * 
+     * @access protected
+     * @param int
+     */
+    var $default_priority = 5;
+    /**
+     * åǥ쥯ȥ̾
+     * 
+     * @access protected
+     * @param string
+     */
+    var $cache_dir_name = '';
+    /**
+     * ƥȥ֥
+     * 
+     * @access protected
+     * @param object
+     */
+    var $context = null;
     /**
      * XMLե̾
      * 
@@ -67,12 +95,6 @@ class SyL_Config extends SyL_XmlReader
      * @var array
      */
     var $config = array();
-    /**
-     * ǥեȼ¹Խ
-     * 
-     * @param int
-     */
-    var $default_priority = 5;
 
     /**
      * 󥹥ȥ饯
@@ -100,19 +122,21 @@ class SyL_Config extends SyL_XmlReader
     {
         $class_name = 'SyL_Config' . ucfirst($config_name);
         include_once SYL_INCLUDE_DIR . "/framework/Config/{$class_name}.php";
-        $obj =& new $class_name($file_names);
-        $obj->setController($controller);
+        $obj = new $class_name($file_names);
+        $obj->setContext($controller);
         return $obj;
     }
 
     /**
-     * ȥ򥻥å
+     * ƥȤ򥻥å
      *
-     * @access public
+     * @access protected
      * @param object ȥ饪֥
      */
-    function setController(&$controller)
+    function setContext(&$controller)
     {
+        $container =& $controller->getContainer();
+        $this->context =& $container->getComponent('context');
     }
 
     /**
@@ -138,6 +162,9 @@ class SyL_Config extends SyL_XmlReader
         $cache->setPrefix(basename($this->file_names[0]) . '.');
         $cache->setKey($key);
         $cache->setMinModifyTime($mtime);
+        if (defined('SYL_CACHE_FILE_DIR') && SYL_CACHE_FILE_DIR) {
+            $cache->setCacheDir(SYL_CACHE_FILE_DIR . basename($this->file_names[0]) . '/');
+        }
 
         //$cache->useIncludeCache();
 
