@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Container.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Container.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Container
@@ -130,7 +130,7 @@ class SyL_Container
 
         // ƥʤ
         if ($event == 'finalStream') {
-            $this->log('debug', "$event event global config ..." . print_r($this->config, true));
+            //$this->log('debug', "$event event global config ..." . print_r($this->config, true));
             //$this->log('debug', "$event event application config ..." . print_r($this->app_config, true));
         }
 /*
@@ -278,7 +278,7 @@ echo "</pre>";
                         // ͽʤ᥽åɤμ¹Ԥϥ顼
                         if (class_exists('SyL_Response')) {
                             $this->log('warn', "Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})");
-                            SyL_Response::redirect404();
+                            SyL_Response::forward404();
                         } else {
                             trigger_error("[SyL error] Method injection failed: method not found (" . get_class($component) . ".{$funcs[1]})", E_USER_ERROR);
                         }
