@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.11 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.12 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.11 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.12 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -236,9 +236,10 @@ class SyL_Context
      * ƥץ졼ȥե
      * 
      * @access public
+     * @param bool 404顼ưե饰
      * @return string ƥץ졼ȥե
      */
-    function getTemplateFile()
+    function getTemplateFile($trigger_error_404=true)
     {
         $template_dir  = $this->getTemplateDir();
         $template_file = $this->template_file;
@@ -250,7 +251,7 @@ class SyL_Context
         SyL_Loggers::debug("[Context] Template dir: {$template_dir} file: {$template_file}");
 
         // ƥץ졼ȥե¸ߥå
-        if (!is_file($template_dir . $template_file)) {
+        if ($trigger_error_404 && !is_file($template_dir . $template_file)) {
             SyL_Loggers::warn("[Context] Template file not found dir: {$template_dir} file: {$template_file}");
             SyL_Response::forward404();
         }
