@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.24 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.25 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.24 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.25 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -202,7 +202,7 @@ class SyL_Error
         // 顼å
         $error_messages = SYL_ERROR ? $this->getErrorMessages() : array(SYL_ERROR_MESSAGE);
         // 顼ȥ졼μ
-        $error_trace = SYL_ERROR_TRACE ? $this->getTrace() : '';
+        $error_trace = SYL_ERROR ? $this->getTrace() : array();
 
         // ֥饹
         $this->displayError($error_messages, $error_trace);
@@ -311,6 +311,11 @@ class SyL_Error
             $error_message .= "[line] "     . $values['line']     . " ";
             $error_message .= "[function] " . $values['function'] . $this->eol;
         }
+        if (isset($_SERVER['REQUEST_METHOD']))  $error_message .= 'REQUEST_METHOD: '  . $_SERVER['REQUEST_METHOD']  . $this->eol;
+        if (isset($_SERVER['REQUEST_URI']))     $error_message .= 'REQUEST_URI: '     . $_SERVER['REQUEST_URI']     . $this->eol;
+        if (isset($_SERVER['HTTP_REFERER']))    $error_message .= 'REFERRER: '        . $_SERVER['HTTP_REFERER']    . $this->eol;
+        if (isset($_SERVER['HTTP_USER_AGENT'])) $error_message .= 'USER_AGENT: '      . $_SERVER['HTTP_USER_AGENT'] . $this->eol;
+
         return $error_message;
     }
 
@@ -345,6 +350,9 @@ class SyL_Error
     {
         // ȥ졼դ顼å
         $error_message  = $this->getErrorMessageTrace();
+        $error_message .= 'GET : '  . print_r($_GET, true);
+        $error_message .= 'POST : ' . print_r($_POST, true);
+
         // 顼٥˥¸
         switch ($this->controller->getErrorNo()) {
         case E_ERROR:
@@ -378,10 +386,6 @@ class SyL_Error
                 $server = isset($_SERVER['SERVER_NAME']) ? $_SERVER['SERVER_NAME'] : '';
             }
 
-            $request_uri = isset($_SERVER['REQUEST_URI'])         ? $_SERVER['REQUEST_URI']     : '';
-            $user_agent  = isset($_SERVER['HTTP_USER_AGENT'])     ? $_SERVER['HTTP_USER_AGENT'] : '';
-            $server_software = isset($_SERVER['SERVER_SOFTWARE']) ? $_SERVER['SERVER_SOFTWARE'] : '';
-
             // ȥ졼դ顼å
             $error_message  = $this->getErrorMessageTrace();
             // SyLΥС
@@ -394,15 +398,11 @@ class SyL_Error
 SyL Framework Error info.
 ----------------------------------------
 DATE: {$date}
-SERVER: {$server}
-REQUEST_URI: {$request_uri}
-HTTP_USER_AGENT: {$user_agent}
 
 {$error_message}
 
 ----------------------------------------
 SyL Framework ver. {$version} on PHP {$version_php}
-{$server_software}
 {$uname}
 EOF;
 
