@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.14 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.15 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Filter.php,v 1.14 2007/04/30 13:15:57 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Filter.php,v 1.15 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  **/
 class SyL_Filter
@@ -82,16 +82,6 @@ class SyL_Filter
     function postRender()
     {
     }
-
-    /**
-     * 󥿡ե᥽å
-     *
-     * @access public
-     */
-    function affect()
-    {
-        return null;
-    }
 }
 
 ?>
