@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,32 +39,11 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Logger.php,v 1.13 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Logger.php,v 1.14 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Logger
 {
-    /**
-     * ꥯȥ᥽å
-     * 
-     * @access protected
-     * @var string
-     */
-    var $request_method;
-    /**
-     * 饤IPɥ쥹
-     * 
-     * @access protected
-     * @var string
-     */
-    var $remote_addr;
-    /**
-     * ꥯURL
-     * 
-     * @access protected
-     * @var string
-     */
-    var $request_uri;
     /**
      * ¨ϥե饰
      * 
@@ -103,15 +82,6 @@ class SyL_Logger
      */
     function SyL_Logger($immediate=true)
     {
-        if (SYL_ENV_TYPE == 'cmd') {
-            $this->request_method = 'php';
-            $this->remote_addr    = '127.0.0.1';
-            $this->request_uri    = isset($_SERVER['SCRIPT_FILENAME']) ? $_SERVER['SCRIPT_FILENAME'] : '';
-        } else {
-            $this->request_method = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '';
-            $this->remote_addr    = isset($_SERVER['REMOTE_ADDR'])    ? $_SERVER['REMOTE_ADDR']    : '';
-            $this->request_uri    = isset($_SERVER['REQUEST_URI'])    ? $_SERVER['REQUEST_URI']    : '';
-        }
         $this->immediate = $immediate;
     }
 
