@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.8 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.9 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_SMARTY_DIR . 'Smarty.class.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.8 2007/05/27 16:24:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutSmarty.php,v 1.9 2007/06/24 10:44:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutSmarty extends SyL_ViewLayout
@@ -93,11 +93,6 @@ class SyL_ViewLayoutSmarty extends SyL_ViewLayout
             }
         }
 
-        // ӥ塼ɽ󥯥롼ɥե
-        foreach ($this->getIncludeFiles() as $include_file) {
-            include_once $include_file;
-        }
-
         // ƥץ졼ȥǥ쥯ȥꥻå
         $this->smarty->template_dir = $this->getTemplateDir();
         // ɽƤ򥻥å
