@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchemaPgsql.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchemaPgsql.php,v 1.3 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchemaPgsql.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchemaPgsql.php,v 1.3 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSchemaPgsql extends SyL_DBSchema
@@ -74,6 +74,8 @@ class SyL_DBSchemaPgsql extends SyL_DBSchema
             $sql .=   "c.relkind IN ('r', 'v') AND ";
             $sql .=   "(v.viewname  IS NULL AND t.tablename IS NOT NULL AND t.schemaname <> 'information_schema' AND t.tablename NOT LIKE 'pg\\_%') OR ";
             $sql .=   "(t.tablename IS NULL AND v.viewname  IS NOT NULL AND v.schemaname <> 'information_schema' AND v.viewname  NOT LIKE 'pg\\_%') ";
+            $sql .= "ORDER BY ";
+            $sql .=   "c.relname ";
         } else {
             $sql .= "SELECT ";
             $sql .=   "c.relname, ";
@@ -85,6 +87,8 @@ class SyL_DBSchemaPgsql extends SyL_DBSchema
             $sql .= "WHERE ";
             $sql .=   "c.relkind IN ('r', 'v') AND ";
             $sql .=   "c.relname NOT LIKE 'pg\\_%' ";
+            $sql .= "ORDER BY ";
+            $sql .=   "c.relname ";
         }
 
         $result = array();
