@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableRelations.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableRelations.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableRelations.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableRelations.php,v 1.3 2007/10/15 13:56:43 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSqlTableRelations
@@ -56,9 +56,10 @@ class SyL_DBSqlTableRelations
      * ʸ
      *
      * @access public
+     * @param object ͥ󥪥֥
      * @return string SQLʸ
      */
-    function getJoin()
+    function getJoin(&$conn)
     {
         $from = '';
         $first = true;
@@ -116,25 +117,58 @@ class SyL_DBSqlTableRelations
                 $aliases[] = $condition[1]['alias'];
             }
             $from .= "ON " . implode(' AND ', $condition[3]) . ' ';
+            if (is_object($condition[4])) {
+                $from .= ' AND ' . $condition[4]->getWhere($conn) . ' ';
+            }
         }
 
         return $from;
     }
 
+    /**
+     * addInnerJoin᥽åɤΥꥢ
+     *
+     * @access public
+     * @param object ơ֥륪֥1
+     * @param object ơ֥륪֥2
+     * @param array Ϣ
+     * @param object 索֥
+     */
+    function addJoin($table1, $table2, $columns, $condition=null)
+    {
+        $this->addInnerJoin($table1, $table2, $columns, $condition);
+    }
+
     /**
      * 
      *
      * @access public
      * @param object ơ֥륪֥1
      * @param object ơ֥륪֥2
-     * @param string 黻
      * @param array Ϣ
+     * @param object 索֥
      */
-    function addJoin($table1, $table2, $operator, $columns)
+    function addInnerJoin($table1, $table2, $columns, $condition=null)
     {
         $column1 = array('name' => $table1->getName(), 'alias' => $table1->getAliasName());
         $column2 = array('name' => $table2->getName(), 'alias' => $table2->getAliasName());
-        $this->add($column1, $column2, $operator, $columns);
+        $this->add($column1, $column2, '=', $columns, $condition);
+    }
+
+    /**
+     * ʺ
+     *
+     * @access public
+     * @param object ơ֥륪֥1
+     * @param object ơ֥륪֥2
+     * @param array Ϣ
+     * @param object 索֥
+     */
+    function addLeftJoin($table1, $table2, $columns, $condition=null)
+    {
+        $column1 = array('name' => $table1->getName(), 'alias' => $table1->getAliasName());
+        $column2 = array('name' => $table2->getName(), 'alias' => $table2->getAliasName());
+        $this->add($column1, $column2, '+', $columns, $condition);
     }
 
     /**
@@ -145,7 +179,7 @@ class SyL_DBSqlTableRelations
      * @param array ̾2
      * @param string 黻
      */
-    function add($column1, $column2, $operator, $columns)
+    function add($column1, $column2, $operator, $columns, $condition)
     {
         switch ($operator) {
         case '=':
@@ -154,7 +188,7 @@ class SyL_DBSqlTableRelations
         default:
             trigger_error("[SyL error] Not supported operator ({$operator})", E_USER_ERROR);
         }
-        $this->conditions[] = array($column1, $column2, $operator, $columns);
+        $this->conditions[] = array($column1, $column2, $operator, $columns, $condition);
     }
 }
 
