@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.22 2007/10/15 13:56:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.23 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.22 2007/10/15 13:56:44 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.23 2007/11/04 13:44:14 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -55,7 +55,14 @@ class SyL_DB
      * @access protected
      * @var string
      */
-    var $dbname = '';
+    var $dbtype = '';
+    /**
+     * ³
+     * 
+     * @access protected
+     * @var array
+     */
+    var $dsn = array();
     /**
      * ͥ꥽ or ֥
      * 
@@ -158,7 +165,7 @@ class SyL_DB
     function SyL_DB($dbtype)
     {
         set_magic_quotes_runtime(0);
-        $this->dbname = $dbtype;
+        $this->dbtype = $dbtype;
 
         $this->callback_sql_log   = array(&$this, 'logSql');
         $this->callback_error_log = array(&$this, 'logError');
@@ -247,6 +254,51 @@ class SyL_DB
      */
     function closeConnection() {}
 
+    /**
+     * DB³ɥ饤̾
+     * 
+     * @access public
+     * @return string DB³ɥ饤̾
+     */
+    function getType()
+    {
+        return $this->dbtype;
+    }
+
+    /**
+     * DB³򥻥åȤ
+     * 
+     * @access public
+     * @param string ǡ١̾
+     * @param string 桼̾
+     * @param string ѥ
+     * @param string ۥ̾
+     * @param string ݡֹ
+     * @param string ³Ū³Ԥ
+     */
+    function setDsnInfo($dbname, $user, $passwd, $host, $port, $persistent)
+    {
+        $this->dsn = array(
+            'db'         => $dbname,
+            'user'       => $user,
+            'password'   => $passwd,
+            'host'       => $host,
+            'port'       => $port,
+            'persistent' => $persistent
+        );
+    }
+
+    /**
+     * DB³
+     * 
+     * @access public
+     * @return array DB³
+     */
+    function getDsnInfo()
+    {
+        return $this->dsn;
+    }
+
     /**
      * DB饤¦ʸ󥳡ƥ
      * 
@@ -937,18 +989,6 @@ class SyL_DB
         return SyL_DBSchema::factory($this);
     }
 
-    /**
-     * ꤷơ֥Υ
-     *
-     * @access public
-     * @param string ơ֥̾
-     * @return array 
-     */
-    function getColumns($tablename)
-    {
-        $schema =& SyL_DBSchema::factory($this);
-        return $schema->getColumns($tablename);
-    }
 }
 
 ?>
