@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.3 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.4 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilUserAgent
@@ -88,6 +88,7 @@ class SyL_UtilUserAgent
       'netbsd'          => 'NetBSD',
       'openbsd'         => 'OpenBSD',
       'gnu'             => 'GNU/Linux',
+      ' vine'           => 'Vine Linux',
       'linux'           => 'Linux',
       'unix'            => 'Unknown Unix OS',
 
@@ -122,6 +123,7 @@ class SyL_UtilUserAgent
       'Konqueror'         => 'Konqueror',
       'hotjava'           => 'HotJava',
       'Lynx'              => 'Lynx',
+      'jig browser'       => 'jig browser',
 
       'sharp pda browser' => 'ZAURUS',
       'AVE-Front'         => 'AVE-Front',
@@ -170,8 +172,8 @@ class SyL_UtilUserAgent
       'Yahoo-MMCrawler'  => 'Yahoo-MMCrawler',
       'Yahoo! Slurp'     => 'Yahoo! Slurp',
       'Y!J-'             => 'Y!J',
-      'msnbot-media'     => 'msnbot-media',
       'msnbot-NewsBlogs' => 'msnbot-NewsBlogs',
+      'msnbot-media'     => 'msnbot-media',
       'msnbot'           => 'msnbot',
       'Yeti'             => 'YetiBot',
       'Baiduspider'      => 'Baiduspider',
